# Insurance Coverage
| State | Requires Coverage | Private Coverage No Restrictions | Private Coverage Exception Life | Private Coverage Exception Health | Private Coverage Exception Fetal | Private Coverage Exception Rape or Incest | Exchange Coverage No Restrictions | Exchange Coverage Exception Life | Exchange Coverage Exception Health | Exchange Coverage Exception Fetal | Exchange Coverage Exception Rape or Incest | Exchange Coverage Forbids Coverage | Medicaid Coverage Provider Patient Decision | Medicaid Coverage Exception Life | Medicaid Coverage Exception Health | Medicaid Coverage Exception Fetal | Medicaid Coverage Exception Rape or Incest | Last Updated |
| ----- | ----------------- | -------------------------------- | ------------------------------- | --------------------------------- | -------------------------------- | ----------------------------------------- | --------------------------------- | -------------------------------- | ---------------------------------- | --------------------------------- | ------------------------------------------ | ---------------------------------- | ------------------------------------------- | -------------------------------- | ---------------------------------- | --------------------------------- | ------------------------------------------ | ------------ |
| Alabama | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| Alaska | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Arizona | No exception | True | No exception | No exception | No exception | No exception | No exception | True | Major Bodily Function | No exception | No exception | No exception | No exception | True | No exception | No exception | True | 2021-05-21T22:18:09.000Z |
| Arkansas | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| California | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | 2019-11-13T12:10:29.000Z |
| Colorado | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Connecticut | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Delaware | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| District of Columbia | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Florida | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| Georgia | No exception | True | No exception | No exception | No exception | No exception | No exception | True | Major Bodily Function | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Hawaii | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Idaho | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| Illinois | True | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | 2019-07-02T11:35:00.000Z |
| Indiana | No exception | No exception | True | Major Bodily Function | No exception | True | No exception | True | Major Bodily Function | No exception | True | No exception | No exception | True | Physical | No exception | True | No date available |
| Iowa | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | Serious fetal anomaly | True | No date available |
| Kansas | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | 2021-05-21T22:14:13.000Z |
| Kentucky | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Louisiana | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | True | No exception | No exception | True | No date available |
| Maine | True | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | 2019-11-13T12:09:56.000Z |
| Maryland | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Massachusetts | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Michigan | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Minnesota | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Mississippi | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | Serious fetal anomaly | True | No date available |
| Missouri | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Montana | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Nebraska | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Nevada | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| New Hampshire | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| New Jersey | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| New Mexico | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| New York | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | 2019-11-13T12:10:25.000Z |
| North Carolina | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| North Dakota | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Ohio | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| Oklahoma | No exception | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Oregon | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | True | No exception | No exception | No exception | No date available |
| Pennsylvania | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| Rhode Island | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| South Carolina | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No exception | No exception | True | No date available |
| South Dakota | No exception | True | No exception | No exception | No exception | No exception | No exception | True | Major Bodily Function | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No date available |
| Tennessee | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | True | No exception | No exception | True | No date available |
| Texas | No exception | No exception | True | Major Bodily Function | No exception | No exception | No exception | True | Major Bodily Function | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |
| Utah | No exception | No exception | True | Major Bodily Function | Lethal fetal anomaly | True | No exception | True | Major Bodily Function | Lethal fetal anomaly | True | No exception | No exception | True | Physical | No exception | True | No date available |
| Vermont | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| Virginia | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | Serious fetal anomaly | True | 2021-05-21T22:14:49.000Z |
| Washington | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No date available |
| West Virginia | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | Major Bodily Function | Serious fetal anomaly | True | No date available |
| Wisconsin | No exception | True | No exception | No exception | No exception | No exception | No exception | True | Physical | No exception | True | No exception | No exception | True | Physical | No exception | True | 2021-05-21T22:13:01.000Z |
| Wyoming | No exception | True | No exception | No exception | No exception | No exception | True | No exception | No exception | No exception | No exception | No exception | No exception | True | No exception | No exception | True | No date available |